@@ -24,18 +24,18 @@ PersMonNonMixWei <- function(lambda, k, c, n.alive, new.pat, cont.time) {
     c^exp(- lambda * x^k)
   }
   Integrand3 <- function(x) {
-    (integrate(f    = Integrand2,
-               lower = 0,
-               upper = x)$value * c^(1 - exp(- lambda * x^k)))
+    (stats::integrate(f    = Integrand2,
+                      lower = 0,
+                      upper = x)$value * c^(1 - exp(- lambda * x^k)))
   }
 
   # calculation of further person months
-  O.star <- (n.alive * integrate(f     = Integrand1,
-                                 lower = 0,
-                                 upper = cont.time)$value
-              + new.pat / c * integrate(f     = Vectorize(Integrand3),
+  O.star <- (n.alive * stats::integrate(f     = Integrand1,
                                         lower = 0,
-                                        upper = cont.time)$value)
+                                        upper = cont.time)$value
+              + new.pat / c * stats::integrate(f     = Vectorize(Integrand3),
+                                               lower = 0,
+                                               upper = cont.time)$value)
 
   return(O.star)
 }
\ No newline at end of file
